==> rdf4j-sail-inferencer-2.0-sources.jar: org/eclipse/rdf4j/sail/inferencer/fc/config/DirectTypeHierarchyInferencerFactory.java <==
/*******************************************************************************
 * Copyright (c) 2015 Eclipse RDF4J contributors, Aduna, and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Distribution License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *******************************************************************************/
package org.eclipse.rdf4j.sail.inferencer.fc.config;

import org.eclipse.rdf4j.sail.Sail;
import org.eclipse.rdf4j.sail.config.SailConfigException;
import org.eclipse.rdf4j.sail.config.SailFactory;
import org.eclipse.rdf4j.sail.config.SailImplConfig;
import org.eclipse.rdf4j.sail.inferencer.fc.DirectTypeHierarchyInferencer;

/**
 * A {@link SailFactory} that creates {@link DirectTypeHierarchyInferencer}s based on RDF configuration data.
 * 
 * @author Arjohn Kampman
 */
public class DirectTypeHierarchyInferencerFactory implements SailFactory {

	/**
	 * The type of repositories that are created by this factory.
	 * 
	 * @see SailFactory#getSailType()
	 */
	public static final String SAIL_TYPE = "openrdf:DirectTypeHierarchyInferencer";

	/**
	 * Returns the Sail's type: <tt>openrdf:DirectTypeHierarchyInferencer</tt>.
	 */
	public String getSailType() {
		return SAIL_TYPE;
	}

	public SailImplConfig getConfig() {
		return new DirectTypeHierarchyInferencerConfig();
	}

	public Sail getSail(SailImplConfig config)
		throws SailConfigException
	{
		if (!SAIL_TYPE.equals(config.getType())) {
			throw new SailConfigException("Invalid Sail type: " + config.getType());
		}

		return new DirectTypeHierarchyInferencer();
	}
}

==> rdf4j-sail-inferencer-4.3.8-sources.jar: org/eclipse/rdf4j/sail/inferencer/fc/config/DirectTypeHierarchyInferencerFactory.java <==
/*******************************************************************************
 * Copyright (c) 2015 Eclipse RDF4J contributors, Aduna, and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Distribution License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *******************************************************************************/
package org.eclipse.rdf4j.sail.inferencer.fc.config;

import org.eclipse.rdf4j.sail.Sail;
import org.eclipse.rdf4j.sail.config.SailConfigException;
import org.eclipse.rdf4j.sail.config.SailFactory;
import org.eclipse.rdf4j.sail.config.SailImplConfig;
import org.eclipse.rdf4j.sail.inferencer.fc.DirectTypeHierarchyInferencer;

/**
 * A {@link SailFactory} that creates {@link DirectTypeHierarchyInferencer}s based on RDF configuration data.
 *
 * @author Arjohn Kampman
 */
public class DirectTypeHierarchyInferencerFactory implements SailFactory {

	/**
	 * The type of repositories that are created by this factory.
	 *
	 * @see SailFactory#getSailType()
	 */
	public static final String SAIL_TYPE = "openrdf:DirectTypeHierarchyInferencer";

	/**
	 * Returns the Sail's type: <var>openrdf:DirectTypeHierarchyInferencer</var>.
	 */
	@Override
	public String getSailType() {
		return SAIL_TYPE;
	}

	@Override
	public SailImplConfig getConfig() {
		return new DirectTypeHierarchyInferencerConfig();
	}

	@Override
	public Sail getSail(SailImplConfig config) throws SailConfigException {
		if (!SAIL_TYPE.equals(config.getType())) {
			throw new SailConfigException("Invalid Sail type: " + config.getType());
		}

		return new DirectTypeHierarchyInferencer();
	}
}
